@@ -395,6 +395,7 @@ class Fleet:
             verifier_id=verifier_id,  # Set verifier_id so _rebuild_verifier works
             verifier_sha=verifier_sha,  # Set verifier_sha
             metadata=task_json.get("metadata", {}),  # Default empty metadata
+            output_json_schema=task_json.get("output_json_schema"),  # JSON schema for output
         )
         return task
 
@@ -405,6 +406,7 @@ class Fleet:
         version: Optional[str] = None,
         team_id: Optional[str] = None,
         project_key: Optional[str] = None,
+        task_project_key: Optional[str] = None,
         data_id: Optional[str] = None,
         data_version: Optional[str] = None,
     ) -> List[Task]:
@@ -416,6 +418,7 @@ class Fleet:
             version: Optional version to filter tasks by (client-side filter)
             team_id: Optional team_id to filter by (admin only)
             project_key: Optional project key to filter tasks by
+            task_project_key: Optional task project key to filter tasks by
             data_id: Optional data identifier to filter tasks by
             data_version: Optional data version to filter tasks by
 
@@ -431,6 +434,8 @@ class Fleet:
             params["team_id"] = team_id
         if project_key is not None:
             params["project_key"] = project_key
+        if task_project_key is not None:
+            params["task_project_key"] = task_project_key
         if data_id is not None:
             params["data_id"] = data_id
         if data_version is not None:
@@ -553,6 +558,7 @@ class Fleet:
                 verifier_func=verifier_func,  # Set verifier code
                 verifier=verifier,  # Use created verifier or None
                 metadata={},  # Default empty metadata
+                output_json_schema=getattr(task_response, "output_json_schema", None),  # Get output_json_schema if available
             )
             tasks.append(task)
 
@@ -715,6 +721,33 @@ class Fleet:
         )
         return TaskResponse(**response.json())
 
+    def get_task(
+        self,
+        task_key: str,
+        version_id: Optional[str] = None,
+        team_id: Optional[str] = None,
+    ) -> TaskResponse:
+        """Get a task by key and optional version.
+
+        Args:
+            task_key: The key of the task to retrieve
+            version_id: Optional version ID to filter by
+            team_id: Optional team_id to filter by (admin only)
+
+        Returns:
+            TaskResponse containing the task details
+        """
+        params = {}
+        if version_id is not None:
+            params["version_id"] = version_id
+        if team_id is not None:
+            params["team_id"] = team_id
+
+        response = self.client.request(
+            "GET", f"/v1/tasks/{task_key}", params=params
+        )
+        return TaskResponse(**response.json())
+
     def _create_verifier_from_data(
         self, verifier_id: str, verifier_key: str, verifier_code: str, verifier_sha: str
     ) -> "SyncVerifierFunction":
