@@ -26,6 +26,8 @@ class Task(BaseModel):
     )
     created_at: Optional[datetime] = Field(None, description="Task creation timestamp")
     version: Optional[str] = Field(None, description="Task version")
+    data_id: Optional[str] = Field(None, description="Data identifier")
+    data_version: Optional[str] = Field(None, description="Data version")
     verifier_func: Optional[str] = Field(None, description="Verifier function code")
     verifier: Optional[Any] = Field(
         None,
@@ -37,6 +39,9 @@ class Task(BaseModel):
     metadata: Optional[Dict[str, Any]] = Field(
         default_factory=dict, description="Additional task metadata"
     )
+    output_json_schema: Optional[Dict[str, Any]] = Field(
+        None, description="JSON schema for expected output format"
+    )
 
     @validator("key")
     def validate_key_format(cls, v):
@@ -59,6 +64,15 @@ class Task(BaseModel):
             return f"{self.env_id}:{self.version}"
         return self.env_id
 
+    @property
+    def data_key(self) -> Optional[str]:
+        """Get the data key combining data_id and data_version."""
+        if self.data_id and self.data_version:
+            return f"{self.data_id}:{self.data_version}"
+        elif self.data_id:
+            return self.data_id
+        return None
+
     class Config:
         """Pydantic model configuration."""
 
@@ -200,6 +214,40 @@ class Task(BaseModel):
 
         return Fleet().make(env_key=self.env_key, region=region)
 
+    def make(self, region: Optional[str] = None, image_type: Optional[str] = None):
+        """Create an environment instance with task's configuration.
+
+        Auto-populates environment creation with:
+        - env_key (env_id + version)
+        - data_key (data_id + data_version, if present)
+        - env_variables (if present)
+
+        Args:
+            region: Optional AWS region for the environment
+            image_type: Optional image type for the environment
+
+        Returns:
+            Environment instance configured for this task
+
+        Example:
+            task = fleet.Task(key="my-task", prompt="...", env_id="my-env",
+                            data_id="my-data", data_version="v1.0")
+            env = task.make(region="us-west-2")
+        """
+        if not self.env_id:
+            raise ValueError("Task has no env_id defined")
+
+        # Deferred import to avoid circular dependencies
+        from fleet.env import make
+
+        return make(
+            env_key=self.env_key,
+            data_key=self.data_key,
+            region=region,
+            env_variables=self.env_variables if self.env_variables else None,
+            image_type=image_type,
+        )
+
 
 def verifier_from_string(
     verifier_func: str, verifier_id: str, verifier_key: str, sha256: str = ""
@@ -238,10 +286,12 @@ def verifier_from_string(
         # Execute the verifier code in the namespace
         exec(verifier_func, exec_globals, local_namespace)
 
-        # Find the function that was defined
+        # Find the function that was defined (not imported)
+        # Functions defined via exec have co_filename == '<string>'
+        # Imported functions have their actual module file path
         func_obj = None
         for name, obj in local_namespace.items():
-            if inspect.isfunction(obj):
+            if inspect.isfunction(obj) and obj.__code__.co_filename == "<string>":
                 func_obj = obj
                 break
 
@@ -285,6 +335,9 @@ def load_tasks(
     version: Optional[str] = None,
     team_id: Optional[str] = None,
     project_key: Optional[str] = None,
+    task_project_key: Optional[str] = None,
+    data_id: Optional[str] = None,
+    data_version: Optional[str] = None,
 ) -> List[Task]:
     """Convenience function to load tasks with optional filtering.
 
@@ -293,11 +346,16 @@ def load_tasks(
         keys: Optional list of task keys to filter by
         version: Optional version to filter tasks by
         team_id: Optional team_id to filter by (admin only)
+        project_key: Optional project key to filter tasks by
+        task_project_key: Optional task project key to filter tasks by
+        data_id: Optional data identifier to filter tasks by
+        data_version: Optional data version to filter tasks by
 
     Examples:
-        tasks = await fleet.load_tasks(env_key="fira")
-        tasks = await fleet.load_tasks(keys=["task1", "task2"])
-        tasks = await fleet.load_tasks(env_key="fira", version="v1.0")
+        tasks = fleet.load_tasks(env_key="fira")
+        tasks = fleet.load_tasks(keys=["task1", "task2"])
+        tasks = fleet.load_tasks(env_key="fira", version="v1.0")
+        tasks = fleet.load_tasks(data_id="my-data", data_version="v1.0")
     """
     # Use the global client by default so users can pre-configure it once
     from .global_client import get_client
@@ -309,6 +367,9 @@ def load_tasks(
         version=version,
         team_id=team_id,
         project_key=project_key,
+        task_project_key=task_project_key,
+        data_id=data_id,
+        data_version=data_version,
     )
 
 
@@ -337,6 +398,28 @@ def update_task(
     )
 
 
+def get_task(task_key: str, version_id: Optional[str] = None, team_id: Optional[str] = None):
+    """Convenience function to get a task by key and optional version.
+
+    Args:
+        task_key: The key of the task to retrieve
+        version_id: Optional version ID to filter by
+        team_id: Optional team_id to filter by (admin only)
+
+    Returns:
+        TaskResponse containing the task details
+
+    Examples:
+        response = fleet.get_task("my-task")
+        response = fleet.get_task("my-task", version_id="v1")
+        response = fleet.get_task("my-task", team_id="team-123")
+    """
+    from .global_client import get_client
+
+    client = get_client()
+    return client.get_task(task_key=task_key, version_id=version_id, team_id=team_id)
+
+
 def import_task(task: Task, project_key: Optional[str] = None):
     """Convenience function to import a single task.
 
